==> react-image-annotate-prabath-2.0.11.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useRef } from "react";
import ReactDOM from "react-dom";
import Editor, { examples } from "./Editor";
import Annotator from "../Annotator";
import ErrorBoundaryDialog from "./ErrorBoundaryDialog.js";
export default (function () {
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      annotatorOpen = _useState2[0],
      changeAnnotatorOpen = _useState2[1]; // const [annotatorProps, changeAnnotatorProps] = useState(examples["Custom"]())


  var _useState3 = useState({
    taskDescription: "Annotate each image according to this _markdown_ specification.",
    // regionTagList: [],
    // regionClsList: ["hotdog"],
    regionTagList: ["has-bun"],
    regionClsList: ["hotdog", "not-hotdog"],
    enabledTools: ["select", "create-point", "create-box", "create-polygon"],
    allowComments: true
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      annotatorProps = _useState4[0],
      changeAnnotatorProps = _useState4[1];

  var _useState5 = useState([{
    src: "https://images.unsplash.com/photo-1496905583330-eb54c7e5915a?ixlib=rb-1.2.1&ixid=eyJhcHBfaWQiOjEyMDd9&auto=format&fit=crop&w=634&q=80",
    name: "hot-dogs-1",
    regions: []
  }, {
    src: "https://www.bianchi.com/wp-content/uploads/2019/07/YPB17I555K.jpg",
    name: "bianchi-oltre-xr4",
    regions: []
  }]),
      _useState6 = _slicedToArray(_useState5, 2),
      images = _useState6[0],
      setImages = _useState6[1];

  var _useState7 = useState(),
      _useState8 = _slicedToArray(_useState7, 2),
      lastOutput = _useState8[0],
      changeLastOutput = _useState8[1];

  var childRef = useRef();
  var _dispatch = null;
  return /*#__PURE__*/React.createElement("div", null, annotatorOpen ? /*#__PURE__*/React.createElement(ErrorBoundaryDialog, {
    onClose: function onClose() {
      changeAnnotatorOpen(false);
    }
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("button", {
    onClick: function onClick() {
      console.log(_dispatch);

      _dispatch({
        type: "ADD_REGION",
        region: {
          type: "box",
          id: "20091109719847278",
          color: "#ff0000",
          cls: "test",
          x: 0.22549019607843138,
          y: 0.17509191176470587,
          w: 0.2591911764705882,
          h: 0.2892156862745098,
          open: true
        }
      }); // childRef.current.addRegion();
      // setImages(ps=>{
      //   ps[1].regions.push({
      //     type: "box",
      //     id: "20091109719847178",
      //     color: "#ff0000",
      //     cls: "test",
      //     x: 0.22549019607843138,
      //     y: 0.17509191176470587,
      //     w: 0.2591911764705882,
      //     h: 0.2892156862745098,
      //     open: true,
      //   })
      //   return [...ps]
      // })

    }
  }, "add image"), /*#__PURE__*/React.createElement(Annotator, Object.assign({}, annotatorProps, {
    images: images,
    ref: childRef,
    onInit: function onInit(state, dispatch) {
      console.log("dispatch", dispatch);
      _dispatch = dispatch;
    },
    onDelete: function onDelete(data) {
      console.log("onDelete", data);
    },
    onExit: function onExit(output) {
      // delete (output: any)["lastAction"]
      console.log("onExit", output); // changeLastOutput(output)
      // changeAnnotatorOpen(false)
    }
  })))) : /*#__PURE__*/React.createElement(Editor, {
    lastOutput: lastOutput,
    onOpenAnnotator: function onOpenAnnotator(props) {
      changeAnnotatorProps(props);
      changeAnnotatorOpen(true);
    }
  }));
});

==> react-image-annotate-prabath-2.0.12.tgz: package/DemoSite/index.js <==
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState, useRef } from "react";
import ReactDOM from "react-dom";
import Editor, { examples } from "./Editor";
import Annotator from "../Annotator";
import ErrorBoundaryDialog from "./ErrorBoundaryDialog.js";
export default (function () {
  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      annotatorOpen = _useState2[0],
      changeAnnotatorOpen = _useState2[1]; // const [annotatorProps, changeAnnotatorProps] = useState(examples["Custom"]())


  var _useState3 = useState({
    taskDescription: "Annotate each image according to this _markdown_ specification.",
    // regionTagList: [],
    // regionClsList: ["hotdog"],
    regionTagList: ["has-bun"],
    regionClsList: ["hotdog", "not-hotdog"],
    allowComments: true
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      annotatorProps = _useState4[0],
      changeAnnotatorProps = _useState4[1];

  var _useState5 = useState([{
    src: "https://images.unsplash.com/photo-1496905583330-eb54c7e5915a?ixlib=rb-1.2.1&ixid=eyJhcHBfaWQiOjEyMDd9&auto=format&fit=crop&w=634&q=80",
    name: "hot-dogs-1",
    regions: []
  }, {
    src: "https://www.bianchi.com/wp-content/uploads/2019/07/YPB17I555K.jpg",
    name: "bianchi-oltre-xr4",
    regions: []
  }]),
      _useState6 = _slicedToArray(_useState5, 2),
      images = _useState6[0],
      setImages = _useState6[1];

  var _useState7 = useState(),
      _useState8 = _slicedToArray(_useState7, 2),
      lastOutput = _useState8[0],
      changeLastOutput = _useState8[1];

  var childRef = useRef();
  var _dispatch = null;
  return /*#__PURE__*/React.createElement("div", null, annotatorOpen ? /*#__PURE__*/React.createElement(ErrorBoundaryDialog, {
    onClose: function onClose() {
      changeAnnotatorOpen(false);
    }
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("button", {
    onClick: function onClick() {
      console.log(_dispatch);

      _dispatch({
        type: "ADD_REGION",
        region: {
          type: "box",
          id: "20091109719847278",
          color: "#ff0000",
          cls: "test",
          x: 0.22549019607843138,
          y: 0.17509191176470587,
          w: 0.2591911764705882,
          h: 0.2892156862745098,
          open: true
        }
      }); // childRef.current.addRegion();
      // setImages(ps=>{
      //   ps[1].regions.push({
      //     type: "box",
      //     id: "20091109719847178",
      //     color: "#ff0000",
      //     cls: "test",
      //     x: 0.22549019607843138,
      //     y: 0.17509191176470587,
      //     w: 0.2591911764705882,
      //     h: 0.2892156862745098,
      //     open: true,
      //   })
      //   return [...ps]
      // })

    }
  }, "add image"), /*#__PURE__*/React.createElement(Annotator, {
    hidePrev: false,
    hideNext: false,
    hideClone: true,
    hideSettings: true,
    labelImages: true,
    images: images,
    ref: childRef,
    onInit: function onInit(state, dispatch) {
      console.log("dispatch", dispatch);
      _dispatch = dispatch;
    },
    onDelete: function onDelete(data) {
      console.log("onDelete", data);
    },
    onExit: function onExit(output) {
      // delete (output: any)["lastAction"]
      console.log("onExit", output); // changeLastOutput(output)
      // changeAnnotatorOpen(false)
    }
  }))) : /*#__PURE__*/React.createElement(Editor, {
    lastOutput: lastOutput,
    onOpenAnnotator: function onOpenAnnotator(props) {
      changeAnnotatorProps(props);
      changeAnnotatorOpen(true);
    }
  }));
});
